@@ -126,7 +126,10 @@ class BaseCollectionModel(BaseModel, MutableSequence[T], metaclass=BaseCollectio
         return len(self.__root__)
 
     def __getitem__(self, index):
-        return self.__root__[index]
+        if isinstance(index, slice):
+            return self.__class__(self.__root__[index])
+        else:
+            return self.__root__[index]
 
     def __setitem__(self, index, value):
         self.__root__[index] = self._validate_element(value, index)
@@ -155,8 +158,23 @@ class BaseCollectionModel(BaseModel, MutableSequence[T], metaclass=BaseCollectio
         data = sorted(self.__root__, key=key, reverse=reverse)
         return self.__class__(data)
 
-    def dict(self, *, by_alias=False, **kwargs) -> List[T]:
-        data = super().dict(by_alias=by_alias)
+    def dict(
+        self,
+        *,
+        by_alias=False,
+        skip_defaults: bool = None,
+        exclude_unset: bool = False,
+        exclude_defaults: bool = False,
+        exclude_none: bool = False,
+        **kwargs,
+    ) -> List[T]:
+        data = super().dict(
+            by_alias=by_alias,
+            skip_defaults=skip_defaults,
+            exclude_unset=exclude_unset,
+            exclude_defaults=exclude_defaults,
+            exclude_none=exclude_none,
+        )
         # Original pydantic dict(...) returns a dict of the form {'__root__': [...]}
         # this behavior will be change in ver 2.0
         # https://github.com/samuelcolvin/pydantic/issues/1193
